@@ -19,7 +19,7 @@ from lollypop.sqlcursor import SqlCursor
 from lollypop.utils import translate_artist_name
 from lollypop.database_history import History
 from lollypop.radios import Radios
-from lollypop.define import App, Type
+from lollypop.define import App, Type, StorageType
 from lollypop.logger import Logger
 
 
@@ -42,13 +42,6 @@ class DatabaseUpgrade:
             Upgrade db
             @param db as Database
         """
-        # Migration from gsettings
-        gsettings_version = App().settings.get_value("db-version").get_int32()
-        if gsettings_version != -1:
-            with SqlCursor(db, True) as sql:
-                sql.execute("PRAGMA user_version=%s" % gsettings_version)
-                App().settings.set_value("db-version",
-                                         GLib.Variant("i", -1))
         version = 0
         with SqlCursor(db, True) as sql:
             result = sql.execute("PRAGMA user_version")
@@ -90,6 +83,7 @@ class DatabasePlaylistsUpgrade(DatabaseUpgrade):
            2: "ALTER TABLE playlists ADD smart_enabled INT NOT NULL DEFAULT 0",
            3: "ALTER TABLE playlists ADD smart_sql TEXT",
            4: self.__upgrade_4,
+           5: "ALTER TABLE playlists ADD uri TEXT"
         }
 
 #######################
@@ -155,6 +149,12 @@ class DatabaseAlbumsUpgrade(DatabaseUpgrade):
             33: "ALTER TABLE artists ADD mb_artist_id TEXT",
             34: self.__upgrade_31,
             35: "UPDATE albums SET synced=2 WHERE synced=1",
+            36: self.__upgrade_36,
+            37: self.__upgrade_37,
+            38: """CREATE TABLE albums_timed_popularity (
+                                                album_id INT NOT NULL,
+                                                mtime INT NOT NULL,
+                                                popularity INT NOT NULL)"""
         }
 
 #######################
@@ -645,3 +645,32 @@ class DatabaseAlbumsUpgrade(DatabaseUpgrade):
             f.delete(None)
         except Exception as e:
             Logger.error("DatabaseAlbumsUpgrade::__upgrade_31(): %s", e)
+
+    def __upgrade_36(self, db):
+        """
+            Restore back mtime in tracks
+        """
+        with SqlCursor(db, True) as sql:
+            sql.execute("ALTER TABLE tracks ADD storage_type INT")
+            sql.execute("ALTER TABLE albums ADD storage_type INT")
+            sql.execute("UPDATE tracks SET storage_type=?\
+                         WHERE mtime > 0", (StorageType.COLLECTION,))
+            sql.execute("UPDATE albums SET storage_type=?\
+                         WHERE mtime > 0", (StorageType.COLLECTION,))
+            sql.execute("UPDATE tracks SET storage_type=?\
+                         WHERE mtime = -1", (StorageType.SAVED,))
+            sql.execute("UPDATE albums SET storage_type=?\
+                         WHERE mtime = -1", (StorageType.SAVED,))
+
+    def __upgrade_37(self, db):
+        """
+            Update Type.WEB and Type.COMPILATIONS
+        """
+        App().settings.reset("shown-album-lists")
+        with SqlCursor(db, True) as sql:
+            sql.execute("UPDATE track_genres SET genre_id=-9\
+                         WHERE genre_id=-22")
+            sql.execute("UPDATE album_genres SET genre_id=-9\
+                         WHERE genre_id=-22")
+            sql.execute("UPDATE album_artists SET artist_id=-10\
+                         WHERE artist_id=-2001")
