@@ -14,14 +14,11 @@ from gi.repository import Gtk, GLib, Gio, GdkPixbuf, Gdk, Pango
 
 from gettext import gettext as _
 
-from lollypop.radios import Radios
 from lollypop.logger import Logger
-from lollypop.define import App, ArtSize
+from lollypop.define import App, ArtSize, Type
 from lollypop.utils import get_network_available
-from lollypop.art import Art
 from lollypop.list import LinkedList
-from lollypop.objects import Track
-from lollypop.helper_task import TaskHelper
+from lollypop.objects_radio import Radio
 
 
 class TuneItem:
@@ -35,17 +32,12 @@ class TuneinPopover(Gtk.Popover):
         Popover showing tunin radios
     """
 
-    def __init__(self, radios=None):
+    def __init__(self):
         """
             Init Popover
-            @param radios as Radios
         """
         Gtk.Popover.__init__(self)
         self.__cancellable = Gio.Cancellable()
-        if radios is not None:
-            self.__radios = radios
-        else:
-            self.__radios = Radios()
         self.__timeout_id = None
         self.__history = None
         self.__covers_to_download = []
@@ -158,10 +150,9 @@ class TuneinPopover(Gtk.Popover):
         self.__back_btn.set_sensitive(False)
         self.__home_btn.set_sensitive(False)
         self.__label.set_text(_("Please wait…"))
-        helper = TaskHelper()
-        helper.load_uri_content(uri,
-                                self.__cancellable,
-                                self.__on_uri_content)
+        App().task_helper.load_uri_content(uri,
+                                           self.__cancellable,
+                                           self.__on_uri_content)
 
     def __show_message(self, message=""):
         """
@@ -209,8 +200,8 @@ class TuneinPopover(Gtk.Popover):
                 button.show()
                 child.add(button)
                 image = Gtk.Image.new()
-                image.set_property("width-request", ArtSize.MEDIUM)
-                image.set_property("height-request", ArtSize.MEDIUM)
+                image.set_property("width-request", ArtSize.SMALL)
+                image.set_property("height-request", ArtSize.SMALL)
                 image.show()
                 child.add(image)
                 self.__covers_to_download.append((item, image))
@@ -238,9 +229,9 @@ class TuneinPopover(Gtk.Popover):
         """
         if self.__covers_to_download and not self.__cancellable.is_cancelled():
             (item, image) = self.__covers_to_download.pop(0)
-            helper = TaskHelper()
-            helper.load_uri_content(item.LOGO, self.__cancellable,
-                                    self.__on_image_downloaded, image)
+            App().task_helper.load_uri_content(item.LOGO, self.__cancellable,
+                                               self.__on_image_downloaded,
+                                               image)
 
     def __clear(self):
         """
@@ -256,36 +247,11 @@ class TuneinPopover(Gtk.Popover):
             Add selected radio
             @param item as TuneIn Item
         """
-        # Get cover art
-        try:
-            helper = TaskHelper()
-            helper.load_uri_content(item.LOGO,
-                                    None,
-                                    self.__on_logo_uri_content,
-                                    item.TEXT)
-        except Exception as e:
-            Logger.error("TuneinPopover::__add_radio: %s" % e)
+        App().task_helper.run(App().art.cache_radio_uri,
+                              item.LOGO, item.TEXT)
         # Tunein in embbed uri in ashx files, so get content if possible
-        helper = TaskHelper()
-        helper.load_uri_content(item.URL, self.__cancellable,
-                                self.__on_item_content, item.TEXT)
-
-    def __on_logo_uri_content(self, uri, status, content, name):
-        """
-            Save image
-            @param uri as str
-            @param status as bool
-            @param content as bytes  # The image
-            @param name as str
-        """
-        if status:
-            cache_path_png = "%s/%s.png" % (Art._RADIOS_PATH, name)
-            bytes = GLib.Bytes(content)
-            stream = Gio.MemoryInputStream.new_from_bytes(bytes)
-            pixbuf = GdkPixbuf.Pixbuf.new_from_stream(stream, None)
-            stream.close()
-            pixbuf.savev(cache_path_png, "png", [None], [None])
-            App().art.emit("radio-artwork-changed", name)
+        App().task_helper.load_uri_content(item.URL, self.__cancellable,
+                                           self.__on_item_content, item.TEXT)
 
     def __on_map(self, widget):
         """
@@ -314,7 +280,7 @@ class TuneinPopover(Gtk.Popover):
         """
         if status and content:
             uri = content.decode("utf-8").split("\n")[0]
-        self.__radios.add(name.replace("/", "-"), uri)
+        App().radios.add(name.replace("/", "-"), uri)
 
     def __on_image_downloaded(self, uri, status, content, image):
         """
@@ -325,13 +291,13 @@ class TuneinPopover(Gtk.Popover):
             @param image as Gtk.Image
         """
         if status:
-            bytes = GLib.Bytes(content)
+            bytes = GLib.Bytes.new(content)
             stream = Gio.MemoryInputStream.new_from_bytes(bytes)
             if stream is not None:
                 pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
                     stream,
-                    ArtSize.MEDIUM,
-                    ArtSize.MEDIUM,
+                    ArtSize.SMALL,
+                    ArtSize.SMALL,
                     True,
                     None)
                 stream.close()
@@ -351,18 +317,11 @@ class TuneinPopover(Gtk.Popover):
             self.__scrolled.get_vadjustment().set_value(0.0)
             self.__populate(item.URL)
         elif item.TYPE == "audio":
-            if get_network_available("TUNEIN"):
-                # Cache for toolbar
-                App().task_helper.run(App().art.copy_uri_to_cache,
-                                      item.LOGO, item.TEXT,
-                                      App().window.toolbar.info.art_size,
-                                      App().window.toolbar.info.art_size)
-                # Cache for MPRIS
-                App().task_helper.run(App().art.copy_uri_to_cache,
-                                      item.LOGO, item.TEXT,
-                                      ArtSize.MONSTER, ArtSize.MONSTER)
-            track = Track()
-            track.set_radio(item.TEXT, item.URL)
+            App().task_helper.run(App().art.cache_radio_uri,
+                                  item.LOGO, item.TEXT)
+            track = Radio(Type.RADIOS)
+            track.name = item.TEXT
+            track.set_uri(item.URL)
             App().player.load(track)
         return True
 
